import GLib from 'gi://GLib';
import GObject from 'gi://GObject';
import St from 'gi://St';
import { Extension } from 'resource:///org/gnome/shell/extensions/extension.js';
import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
import * as Main from 'resource:///org/gnome/shell/ui/main.js';
const EXTENSION_TITLE = "Firefox Profiles";
export default class FirefoxProfilesExtension extends Extension {
    _indicator;
    enable() {
        this._indicator = new GFirefoxProfilesIndicator();
        Main.panel.addToStatusArea(this.uuid, this._indicator);
    }
    disable() {
        if (this._indicator) {
            this._indicator.destroy();
            this._indicator = undefined;
        }
    }
}
// -- Indicator --
class FirefoxProfilesIndicator extends PanelMenu.Button {
    constructor() {
        // 0.0 est la valeur de menuAlignment
        super(0.0, 'Firefox Profiles');
        // Shortcut to the menu
        const menu = this.menu;
        this.add_child(new St.Icon({
            icon_name: 'firefox-symbolic', // white version of the Firefox icon
            style_class: 'system-status-icon',
        }));
        getFirefoxProfiles().forEach(profile => {
            let item = new PopupMenu.PopupMenuItem(profile);
            item.connect('activate', () => openFirefoxProfile(profile));
            menu.addMenuItem(item);
        });
    }
}
const GFirefoxProfilesIndicator = GObject.registerClass(FirefoxProfilesIndicator);
// -- Helpers --
/**
 * Get Firefox profiles
 * @returns {Array} - Array of Firefox profiles
 */
function getFirefoxProfiles() {
    let filePath = GLib.get_home_dir() + '/.mozilla/firefox/profiles.ini';
    let fileContent = GLib.file_get_contents(filePath)[1];
    let content = fileContent.toString();
    let namePattern = /Name=(.*)/g;
    let profiles = [];
    let match;
    while ((match = namePattern.exec(content)) !== null) {
        profiles.push(match[1]);
    }
    return profiles;
}
/**
 * Open Firefox with a specific profile.
 *
 * It will call `firefox -P <profile> -no-remote`.
 *
 * @param {string} profile name of the profile
 */
function openFirefoxProfile(profile) {
    const command = `firefox -P ${profile} -no-remote`;
    try {
        const success = GLib.spawn_command_line_async(command);
        if (!success) {
            Main.notify(EXTENSION_TITLE, `[${profile}]: failed to start`);
        }
    }
    catch (e) {
        logError(e, `[${EXTENSION_TITLE}] [${profile}]: failed to start`);
        Main.notify(EXTENSION_TITLE, `[${profile}]: An error occurred`);
    }
}
